.. -*- mode: rst -*-
.. ex: set sts=4 ts=4 sw=4 et tw=79:
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###
  #
  #   See COPYING file distributed along with the NiBabel package for the
  #   copyright and license terms.
  #
  ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ###

.. include:: ../../README.rst

Documentation
=============

* :ref:`User Documentation <manual>` (manual)
* :ref:`API Documentation <api>` (comprehensive reference)
* :ref:`Developer Guidelines <chap_devguide>` (for those who want to contribute)
* :ref:`Development Changelog <changelog>` (see what has changed)
* :ref:`DICOM concepts <dicom>` (details about implementing DICOM reading)
* :ref:`genindex` (access by keywords)
* :ref:`search` (online and offline full-text search)

See also the :ref:`Developer documentation page <devindex>` for development
discussions, release procedure and more.

Authors and Contributors
========================

NiBabel has been written and is maintained by `Matthew Brett`_
and `Michael Hanke`_.  The authors are grateful to the following
people who have contributed to NiBabel (in rough order of appearance):

* `Yaroslav O. Halchenko`_
* Chris Burns
* `Gaël Varoquaux`_
* `Stephan Gerhard`_
* Ian Nimmo-Smith
* Jarrod Millman
* Bertran Thirion
* Thomas Ballinger
* Cindee Madison
* Valentin Haenel
* Alexandre Gramfort
* Christian Haselgrove
* Krish Subramaniam
* Yannick Schwartz
* Bago Amirbekian
* Brendan Moloney
* Félix C. Morency

License reprise
===============

NiBabel is free-software (beer and speech) and covered by the `MIT License`_.
This applies to all source code, documentation, examples and snippets inside
the source distribution (including this website). Please see the
:ref:`appendix of the manual <license>` for the copyright statement and the
full text of the license.

Download and Installation
=========================

Please find detailed :ref:`download and installation instructions
<installation>` in the manual.

Support
=======

If you have problems installing the software or questions about usage,
documentation or something else related to NiBabel, you can post to the NiPy
mailing list.

:Mailing list:  nipy-devel@neuroimaging.scipy.org [subscription_, archive_]

It is recommended that all users subscribe to the mailing list.  The mailing
list is the preferred way to announce changes and additions to the project. The
mailing list archive can also be searched using the *mailing list archive
search* located in the sidebar of the NiBabel home page.

.. _subscription: http://mail.scipy.org/mailman/listinfo/nipy-devel
.. _archive: http://mail.scipy.org/pipermail/nipy-devel

.. include:: links_names.txt


.. toctree::
   :hidden:

   manual
   devel/index
   dicom/dicom
   api
